@@ -6,8 +6,7 @@
 # roxygen namespace tags. Modify with care!
 ## usethis namespace: start
 #' @importFrom lifecycle deprecate_soft
+#' @importFrom lifecycle deprecated
 #' @importFrom tibble tibble
 ## usethis namespace: end
 NULL
-#' @importFrom usethis ui_info ui_value ui_field ui_done ui_code_block ui_code ui_line ui_stop ui_path ui_oops ui_todo ui_warn ui_yeah
-NULL
